import QtQuick 1.1
import com.nokia.meego 1.0
import Charts 1.0
import "Util.js" as Util

Page {
    id: container;
    tools: commonTools

    property string act: "Memory";
    property double margins: appStyle.theme.margins
    property double spacing: appStyle.theme.spacing

    property double fontSizeTitle: appStyle.theme.fontSizeTitle
    property double fontSizeTitle2: appStyle.theme.fontSizeTitle_larger
    property double fontSize: appStyle.theme.fontSize

    property variant memoryColor: appStyle.theme.memoryColor

    Component.onCompleted: { memTimer.start(); }

    Flickable{
        anchors.fill: parent
        contentHeight: childContent.height;
        contentWidth: parent.width;

        Column {
            id: childContent
            spacing: container.spacing
            width: parent.width;
            anchors{
                left: parent.left;
                right: parent.right;
                margins: container.margins
            }

            Item { width: parent.width; height:3; }

            Label{
                text: "System Memory";
                font.pointSize: container.fontSizeTitle2;
                font.bold: true;
            }

            PieChart {
                width: 150;
                height: 150;
                anchors.horizontalCenter: parent.horizontalCenter;
                name: "Memory"
                slices: [
                    PieSlice {
                        id:area1
                        anchors.fill: parent
                        color: container.memoryColor[1]
                        fromAngle: 0; angleSpan: 120
                    },
                    PieSlice {
                        id:area2
                        anchors.fill: parent
                        color: container.memoryColor[2]
                        fromAngle: 120; angleSpan: 50
                    }
                ]
            }

            Item { width: parent.width; height:1; }
            Rectangle{ width:parent.width; height:1; color: appStyle.theme.lineColor; }
            Item { width: parent.width; height:1; }

            LblLbl{
                id: lbl_mem_total
                width: parent.width;
                anchors{
                    left: parent.left
                    leftMargin: 20;
                }
                fontSizeTitle: container.fontSizeTitle
                fontSize: container.fontSize;
                fontColor: container.memoryColor[0]
                margins: container.margins
                spacing: container.spacing
            }
            LblLbl{
                id: lbl_mem_used
                width: parent.width;
                anchors{
                    left: parent.left
                    leftMargin: 20;
                }
                fontSizeTitle: container.fontSizeTitle
                fontSize: container.fontSize;
                fontColor: container.memoryColor[1]
                margins: container.margins
                spacing: container.spacing
            }
            LblLbl{
                id: lbl_mem_free
                width: parent.width;
                anchors{
                    left: parent.left
                    leftMargin: 20;
                }
                fontSizeTitle: container.fontSizeTitle
                fontSize: container.fontSize;
                fontColor: container.memoryColor[2]
                margins: container.margins
                spacing: container.spacing
            }


            Item { width: parent.width; height:3; }

            Label{
                text: "Swap";
                font.pointSize: container.fontSizeTitle2;
                font.bold: true;
            }

            LblLbl{
                id: lbl_swap_total
                width: parent.width;
                anchors{
                    left: parent.left
                    leftMargin: 20;
                }
                fontSizeTitle: container.fontSizeTitle
                fontSize: container.fontSize;
                margins: container.margins
                spacing: container.spacing
            }
            LblLbl{
                id: lbl_swap_used
                width: parent.width;
                anchors{
                    left: parent.left
                    leftMargin: 20;
                }
                fontSizeTitle: container.fontSizeTitle
                fontSize: container.fontSize;
                margins: container.margins
                spacing: container.spacing
            }
            LblLbl{
                id: lbl_swap_free
                width: parent.width;
                anchors{
                    left: parent.left
                    leftMargin: 20;
                }
                fontSizeTitle: container.fontSizeTitle
                fontSize: container.fontSize;
                margins: container.margins
                spacing: container.spacing
            }

            Item { width: parent.width; height: 3; }

            Button{
                text: "Refresh";
                width: parent.width;
                onClicked: { getMemory(); }
            }

            Item { width: parent.width; height:3; }

        }

    }

    Timer {
        id: memTimer
        interval: 3000
        running: true
        repeat: true
        onTriggered:{
            getMemory();
            recLog(act, "Refresh Memory"+ new Date());
        }
    }

    function getMemory(){
        var res = linuxCmd.getMemoryUsage();
        for(var j=0; j<res.length && res.length>0; j++){
            var arr = new Array();
            var val = res[j].split("  ");
            for(var i=0; i<val.length; i++){
                val[i] = Util.trim(val[i]);
                if(val[i]!=="")
                    arr.push(val[i]);
            }

            if(arr.length>0){
                var total = parseInt(Util.trim(arr[1]));
                var used = parseInt(Util.trim(arr[2]));
                var free = parseInt(Util.trim(arr[3]));
                var sum = used+free;

                var used_percent = Util.roundUp(used*100/sum);
                var free_percent = Util.roundUp(free*100/sum);
                if(j==0){
                    lbl_mem_total.setText("Total", total+" MB");
                    lbl_mem_used.setText("Used", used+" MB ("+used_percent+'%'+")");
                    lbl_mem_free.setText("Free", free+" MB ("+free_percent+'%'+")");

                    area1.fromAngle = 0;
                    area1.angleSpan = used_percent/100*360;
                    area2.fromAngle = area1.angleSpan;
                    area2.angleSpan = 360 - area2.fromAngle;
                }else if(j==1){
                    lbl_swap_total.setText("Total", total+" MB");
                    lbl_swap_used.setText("Used", used+" MB ("+used_percent+'%'+")");
                    lbl_swap_free.setText("Free", free+" MB ("+free_percent+'%'+")");
                }
            }
        }
    }
}
