import QtQuick 1.1
import com.nokia.meego 1.0
import Charts 1.0
import "Util.js" as Util

Page {
    id: container;
    tools: commonTools

    property string act: "Process";
    property double margins: appStyle.theme.margins
    property double spacing: appStyle.theme.spacing

    property double fontSizeTitle: appStyle.theme.fontSizeTitle
    property double fontSizeTitle2: appStyle.theme.fontSizeTitle_larger
    property double fontSize: appStyle.theme.fontSize

    property variant processColor: appStyle.theme.processColor
    property int cpu_height: 20;

    Component.onCompleted: { processTimer.start(); }

    ListModel { id:col_cpu; }
    ListModel { id:col_process; }

    Flickable{
        anchors.fill: parent
        contentHeight: childContent.height;
        contentWidth: parent.width;

        Column {
            id: childContent
            spacing: container.spacing
            width: parent.width;
            anchors{
                left: parent.left;
                right: parent.right;
                leftMargin: 20;
                margins: container.margins
            }

            Item { width: parent.width; height: 3; }

            Label{
                text: "Top Processes";
                font.pointSize: container.fontSizeTitle2;
                font.bold: true;
            }

            Row{
                spacing: container.spacing
                width: parent.width;
                Repeater {
                    model: col_cpu
                    Rectangle {
                        width: { if(percent!="0.0") return parseFloat(percent)/100*childContent.width; else return 0; }
                        color: processColor[cind];
                        height: cpu_height;
                    }
                }
            }

            Item { width: parent.width; height: 3; }

            LblLbl{
                width: childContent.width;
                fontSizeTitle: container.fontSizeTitle
                fontSize: container.fontSize;
                fontColor: processColor[cind]
                margins: container.margins
                spacing: container.spacing
                Component.onCompleted: { setText("CPU", "%"); }
            }

            Repeater {
                model: col_cpu
                LblLbl{
                    width: childContent.width;
                    fontSizeTitle: container.fontSizeTitle
                    fontSize: container.fontSize;
                    fontColor: processColor[cind]
                    margins: container.margins
                    spacing: container.spacing
                    Component.onCompleted: { setText(label, percent+"%"); }
                }
            }

            Item { width: parent.width; height:1; }
            Rectangle{ width:parent.width; height:1; color: appStyle.theme.lineColor; }
            Item { width: parent.width; height:1; }

            Row{
                spacing: container.spacing+10
                width: parent.width;
                LblLbl{
                    width: childContent.width;
                    fontSizeTitle: container.fontSizeTitle
                    fontSize: container.fontSize;
                    margins: container.margins
                    spacing: container.spacing
                    Component.onCompleted: { setText("CPU", "Command"); }
                }
            }
            Repeater {
                model: col_process
                Row{
                    spacing: container.spacing+10
                    width: childContent.width;
                    LblLbl{
                        width: childContent.width;
                        fontSizeTitle: container.fontSizeTitle
                        fontSize: container.fontSize;
                        margins: container.margins
                        spacing: container.spacing
                        Component.onCompleted: { setText(val, command); }
                    }
                }
            }

            Item { width: parent.width; height: 3; }

            Button{
                text: "Refresh";
                width: parent.width;
                onClicked: { getProcess(); }
            }

            Item { width: parent.width; height: 3; }

        }

    }

    Timer {
        id: processTimer
        interval: 3000
        running: true
        repeat: true
        onTriggered:{
            getProcess();
            recLog(act, "Refresh Process"+ new Date());
        }
    }

    function getProcess(){
        col_cpu.clear();
        col_process.clear();

        var count_row = 0;
        var res = linuxCmd.getRunProcess();

        for(var j=0; j<res.length && res.length>0; j++){
            if(count_row>10){
                break;
            }

            var content = "";
            var arr = new Array();

            //skip (Mem) j=0 ,2 ,3
            if(j==0||j==2||j==3){}
            else if(j==1){
                var res_in_row = res[j].split("  ");

                for(var res_index in res_in_row){

                    res_in_row[res_index] = Util.trim(res_in_row[res_index]);
                    var res_in_col = res_in_row[res_index].split(" ");

                    for(var ind in res_in_col){
                        res_in_col[ind] = Util.trim(res_in_col[ind]);
                        if(res_in_col[ind]!==""){
                            arr.push(res_in_col[ind]);
                            //recLog("Process",res_in_col[ind]);
                        }
                    }
                }

                if(arr.length>0){
                    count_row++;
                    for(var i=1; i<arr.length; i+=2){
                        content = {"label":arr[i+1]
                            ,"val": arr[i]
                            ,"percent":arr[i].substring(0,arr[i].length-1)
                            ,"cind":col_cpu.count};
                        col_cpu.append(content);
                    }
                }
            }else {
                var cmd_pos = res[j].search(" /");
                if(cmd_pos!=-1){
                    var cpu = res[j].substring(cmd_pos-5, cmd_pos);
                    var cmd = res[j].substring(cmd_pos, res[j].length);

                    if(cpu!=="" && cmd!==""){
                        count_row++;
                        content = {"val": Util.trim(cpu)
                            ,"command":Util.trim(cmd)
                            ,"cind":col_process.count};
                        col_process.append(content);
                    }
                }
            }
        }
    }
}
