import QtQuick 1.1
import com.nokia.meego 1.0
import Charts 1.0
import "Util.js" as Util

Page {
    id: container;
    tools: commonTools

    property string act: "Storage";
    property double margins: appStyle.theme.margins
    property double spacing: appStyle.theme.spacing

    property double fontSizeTitle: appStyle.theme.fontSizeTitle
    property double fontSizeTitle2: appStyle.theme.fontSizeTitle_larger
    property double fontSize: appStyle.theme.fontSize

    property variant storColor: appStyle.theme.storColor

    Component.onCompleted: { getStorage(); }

    Flickable{
        anchors.fill: parent
        contentHeight: childContent.height;
        contentWidth: parent.width;

        Column {
            id: childContent
            spacing: container.spacing
            width: parent.width;
            anchors{
                left: parent.left;
                right: parent.right;
                margins: container.margins
            }

            Item { width: parent.width; height: container.margins; }

            Label{
                text: "Storage";
                font.pointSize: container.fontSizeTitle2;
                font.bold: true;
            }

            PieChart {
                width: 150;
                height: 150;
                anchors.horizontalCenter: parent.horizontalCenter;
                name: "Storage"
                slices: [
                    PieSlice {
                        id:area1
                        anchors.fill: parent
                        color: container.storColor[1]
                        fromAngle: 0; angleSpan: 120
                    },
                    PieSlice {
                        id:area2
                        anchors.fill: parent
                        color: container.storColor[2]
                        fromAngle: 120; angleSpan: 50
                    }
                ]
            }

            Item { width: parent.width; height:1; }
            Rectangle{ width:parent.width; height:1; color: appStyle.theme.lineColor; }
            Item { width: parent.width; height:1; }

            LblLbl{
                id: lbl_stor_total
                width: parent.width;
                anchors{
                    left: parent.left
                    leftMargin: 20;
                }
                fontSizeTitle: container.fontSizeTitle
                fontSize: container.fontSize;
                fontColor: container.storColor[0]
                margins: container.margins
                spacing: container.spacing
            }

            LblLbl{
                id: lbl_stor_used
                width: parent.width;
                anchors{
                    left: parent.left
                    leftMargin: 20;
                }
                fontSizeTitle: container.fontSizeTitle
                fontSize: container.fontSize;
                fontColor: container.storColor[1]
                margins: container.margins
                spacing: container.spacing
            }

            LblLbl{
                id: lbl_stor_free
                width: parent.width;
                anchors{
                    left: parent.left
                    leftMargin: 20;
                }
                fontSizeTitle: container.fontSizeTitle
                fontSize: container.fontSize;
                fontColor: container.storColor[2]
                margins: container.margins
                spacing: container.spacing
            }

            Item { width: parent.width; height: 3; }

            Button{
                text: "Refresh";
                width: parent.width;
                onClicked: { getStorage(); }
            }

            Item { width: parent.width; height: 3; }

        }

    }

    function getStorage(){
        var res = linuxCmd.getHarddiskSpace();
        for(var j=0; j<res.length && res.length>0; j++){
            var arr = new Array();
            var val = res[j].split("  ");
            for(var i=0; i<val.length; i++){
                val[i] = Util.trim(val[i]);
                if(val[i]!=="")
                    arr.push(val[i]);
            }

            if(arr.length>0){
                var total = parseInt(Util.trim(arr[1]));
                var used = parseInt(Util.trim(arr[2]));
                var free = parseInt(Util.trim(arr[3]));
                var sum = used+free;

                var used_percent = Util.roundUp(used*100/sum);
                var free_percent = Util.roundUp(free*100/sum);

                lbl_stor_total.setText("Total", total+" MB");
                lbl_stor_used.setText("Used", used+" MB ("+used_percent+'%'+")");
                lbl_stor_free.setText("Free", free+" MB ("+free_percent+'%'+")");

                area1.fromAngle = 0;
                area1.angleSpan = used_percent/100*360;
                area2.fromAngle = area1.angleSpan;
                area2.angleSpan = 360 - area2.fromAngle;
            }
        }
    }
}
