import QtQuick 1.1
import com.nokia.meego 1.0
import "Util.js" as Util

PageStackWindow {
    id: appWindow

    property string act : "main"

    initialPage: Splash { id:splashPage; isPortrait: appWindow.inPortrait; }

    Component.onCompleted: {
        splashTimer.start();
        theme.inverted = true;
        recLog(act, "Search for Width "+width+" Height"+height);
    }

    // Properties
    AppStateVars { id: appState; }

    // Style
    Loader {
        id: appStyle;
        property alias theme: appStyle.item;
        source: "AppStyle.qml";
    }

    Timer {
        id: splashTimer
        interval: 3500
        running: false
        onTriggered:{
            recLog(act, "Closing Splash Screen");
            pageStack.replace(memPage);
        }
    }

    Memory { id: memPage; }
    Storage { id: storPage; }
    Process { id: proPage; }
    LinuxExec { id: execPage; }
    About { id: aboutPage; }

    ToolBarLayout {
        id: commonTools
        visible: true
        ToolIcon {
            id: backBtn
            visible: pageStack.depth > 1
            platformIconId: "toolbar-back"
            onClicked: {
                pageStack.pop();
            }
        }

        ButtonRow {
            visible: pageStack.currentPage!=splashPage;
            checkedButton: memTab
            ToolIcon {
                id: memTab
                iconSource: "qrc:/img/memory.png"
                onClicked: { swithPage(memPage); }
            }
            ToolIcon {
                id: storTab
                iconSource: "qrc:/img/storage.png"
                onClicked: { swithPage(storPage); }
            }
            ToolIcon {
                id: proTab
                iconSource: "qrc:/img/process.png"
                onClicked: { swithPage(proPage); }
            }
            ToolIcon {
                id: aboutTab
                iconSource: "qrc:/img/about.png"
                onClicked: { swithPage(aboutPage); }
            }
            /*ToolIcon {
                id: tab5
                platformIconId: "toolbar-settings"
                onClicked: { swithPage(execPage); }
            }*/
        }
        ToolIcon {
            id: switchBtn
            visible: pageStack.currentPage!=splashPage;
            platformIconId: "toolbar-refresh"
            onClicked: { theme.inverted = !theme.inverted; }
        }
    }

    function swithPage(pg){
        if(pageStack.currentPage!==pg)
            pageStack.replace(pg);
    }

    function recLog(tag, message) {
        Util.log("[" + tag + "] : " + message);
    }
}
